# coding: utf-8

"""
    bxb API

    A comprehensive usage-based billing platform API. Manage customers, plans, subscriptions, invoices, payments, wallets, coupons, credit notes, taxes, webhooks, and more.

    The version of the OpenAPI document: 0.5.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from uuid import UUID
from typing import Optional, Set
from typing_extensions import Self

class PortalNextBillingInfo(BaseModel):
    """
    Next billing date info for a single subscription.
    """ # noqa: E501
    subscription_id: UUID
    subscription_external_id: StrictStr
    plan_name: StrictStr
    plan_interval: StrictStr
    next_billing_date: datetime
    days_until_next_billing: StrictInt
    amount_cents: StrictInt
    currency: StrictStr
    __properties: ClassVar[List[str]] = ["subscription_id", "subscription_external_id", "plan_name", "plan_interval", "next_billing_date", "days_until_next_billing", "amount_cents", "currency"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PortalNextBillingInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PortalNextBillingInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "subscription_id": obj.get("subscription_id"),
            "subscription_external_id": obj.get("subscription_external_id"),
            "plan_name": obj.get("plan_name"),
            "plan_interval": obj.get("plan_interval"),
            "next_billing_date": obj.get("next_billing_date"),
            "days_until_next_billing": obj.get("days_until_next_billing"),
            "amount_cents": obj.get("amount_cents"),
            "currency": obj.get("currency")
        })
        return _obj


